@@ -1,15 +1,19 @@
 from django.urls import path
 
-from .views import annotated_tags, bookmarked_objs, filtered_objs
+from .views import annotated_tags, bookmarked_objs, filter_objects_by_tag_model
 
 app_name = "bookmarks"
 urlpatterns = [
     path(
+        "tag/<slug:tag_slug>",
+        filter_objects_by_tag_model,
+        name="filter_objects_by_tag_models",
+    ),
+    path(
         "tag/<slug:tag_slug>/<int:model_id>",
-        filtered_objs,
-        name="filtered_objs",
+        filter_objects_by_tag_model,
+        name="filter_objects_by_tag_models",
     ),
-    path("tag/<slug:tag_slug>", filtered_objs, name="filtered_objs"),
     path("tags", annotated_tags, name="annotated_tags"),
     path("objs", bookmarked_objs, name="bookmarked_objs"),
 ]
