@@ -1,14 +1,10 @@
-from typing import Optional
-
 from django.contrib.auth import get_user_model
 from django.contrib.auth.mixins import LoginRequiredMixin
 from django.contrib.contenttypes.models import ContentType
-from django.http import HttpRequest, HttpResponse
+from django.http import HttpRequest
 from django.template.response import TemplateResponse
 from django.views.generic import DetailView
 
-from bookmarks.utils import Pathmaker
-
 from .models import SampleBook, SampleQuote
 
 
@@ -23,7 +19,7 @@ def homepage_view(request: HttpRequest):
 
 class SampleBookDetail(LoginRequiredMixin, DetailView):
     model = SampleBook
-    template_name = "book_detail.html"
+    template_name = "examples/book_detail.html"
     context_object_name = "book"
 
     def get_context_data(self, **kwargs):
